requests_pelican.director
#########################

.. automodapi:: requests_pelican.director
    :include: get_director_response
    :no-heading:
    :skip: RLock
    :skip: dataclass
    :skip: field
    :skip: get_pelican_configuration
    :skip: get_urls
    :skip: make_url
    :skip: parse_dict_header
    :skip: parse_list_header
    :skip: parse_mirror_link_header
    :skip: parse_url
    :skip: pelican_uri
    :skip: shuffle
